@@ -1035,6 +1035,26 @@ Mat<eT>::operator/=(const diagview<eT>& X)
 
 
 
+template<typename eT>
+inline
+mat_injector< Mat<eT> >
+Mat<eT>::operator<<(const eT val)
+  {
+  return mat_injector< Mat<eT> >(*this, val);
+  }
+
+
+
+template<typename eT>
+inline
+mat_injector< Mat<eT> >
+Mat<eT>::operator<<(const injector_helper x)
+  {
+  return mat_injector< Mat<eT> >(*this, x);
+  }
+
+
+
 //! creation of subview (row vector)
 template<typename eT>
 arma_inline
@@ -2496,11 +2516,24 @@ Mat<eT>::raw_print_trans(std::ostream& user_stream, const std::string extra_text
 template<typename eT>
 inline
 void
-Mat<eT>::set_size(const u32 in_n_rows, const u32 in_n_cols)
+Mat<eT>::set_size(const u32 in_rows, const u32 in_cols)
   {
   arma_extra_debug_sigprint();
   
-  init(in_n_rows, in_n_cols);
+  init(in_rows, in_cols);
+  }
+
+
+
+//! change the matrix to have user specified dimensions (data is preserved)
+template<typename eT>
+inline
+void
+Mat<eT>::reshape(const u32 in_rows, const u32 in_cols, const u32 dim)
+  {
+  arma_extra_debug_sigprint();
+  
+  *this = arma::reshape(*this, in_rows, in_cols, dim);
   }
 
 
@@ -2612,33 +2645,39 @@ Mat<eT>::reset()
 //! save the matrix to a file
 template<typename eT>
 inline
-void
-Mat<eT>::save(const std::string name, const file_type type) const
+bool
+Mat<eT>::save(const std::string name, const file_type type, const bool print_status) const
   {
   arma_extra_debug_sigprint();
   
+  bool save_okay;
+  
   switch(type)
     {
     case raw_ascii:
-      diskio::save_raw_ascii(*this, name);
+      save_okay = diskio::save_raw_ascii(*this, name);
       break;
     
     case arma_ascii:
-      diskio::save_arma_ascii(*this, name);
+      save_okay = diskio::save_arma_ascii(*this, name);
       break;
     
     case arma_binary:
-      diskio::save_arma_binary(*this, name);
+      save_okay = diskio::save_arma_binary(*this, name);
       break;
       
     case pgm_binary:
-      diskio::save_pgm_binary(*this, name);
+      save_okay = diskio::save_pgm_binary(*this, name);
       break;
     
     default:
-      arma_stop("Mat::save(): unsupported file type");
+      arma_warn(print_status, "Mat::save(): unsupported file type");
+      save_okay = false;
     }
   
+  arma_warn( (print_status && (save_okay == false)), "Mat::save(): couldn't write to ", name);
+  
+  return save_okay;
   }
 
 
@@ -2646,33 +2685,39 @@ Mat<eT>::save(const std::string name, const file_type type) const
 //! save the matrix to a stream
 template<typename eT>
 inline
-void
-Mat<eT>::save(std::ostream& os, const file_type type) const
+bool
+Mat<eT>::save(std::ostream& os, const file_type type, const bool print_status) const
   {
   arma_extra_debug_sigprint();
   
+  bool save_okay;
+  
   switch(type)
     {
     case raw_ascii:
-      diskio::save_raw_ascii(*this, "[ostream]", os);
+      save_okay = diskio::save_raw_ascii(*this, os);
       break;
     
     case arma_ascii:
-      diskio::save_arma_ascii(*this, "[ostream]", os);
+      save_okay = diskio::save_arma_ascii(*this, os);
       break;
     
     case arma_binary:
-      diskio::save_arma_binary(*this, "[ostream]", os);
+      save_okay = diskio::save_arma_binary(*this, os);
       break;
       
     case pgm_binary:
-      diskio::save_pgm_binary(*this, "[ostream]", os);
+      save_okay = diskio::save_pgm_binary(*this, os);
       break;
     
     default:
-      arma_stop("Mat::save(): unsupported file type");
+      arma_warn(print_status, "Mat::save(): unsupported file type");
+      save_okay = false;
     }
   
+  arma_warn( (print_status && (save_okay == false)), "Mat::save(): couldn't write to the given stream");
+  
+  return save_okay;
   }
 
 
@@ -2680,37 +2725,59 @@ Mat<eT>::save(std::ostream& os, const file_type type) const
 //! load a matrix from a file
 template<typename eT>
 inline
-void
-Mat<eT>::load(const std::string name, const file_type type)
+bool
+Mat<eT>::load(const std::string name, const file_type type, const bool print_status)
   {
   arma_extra_debug_sigprint();
   
+  bool load_okay;
+  std::string err_msg;
+  
   switch(type)
     {
     case auto_detect:
-      diskio::load_auto_detect(*this, name);
+      load_okay = diskio::load_auto_detect(*this, name, err_msg);
       break;
     
     case raw_ascii:
-      diskio::load_raw_ascii(*this, name);
+      load_okay = diskio::load_raw_ascii(*this, name, err_msg);
       break;
     
     case arma_ascii:
-      diskio::load_arma_ascii(*this, name);
+      load_okay = diskio::load_arma_ascii(*this, name, err_msg);
       break;
     
     case arma_binary:
-      diskio::load_arma_binary(*this, name);
+      load_okay = diskio::load_arma_binary(*this, name, err_msg);
       break;
       
     case pgm_binary:
-      diskio::load_pgm_binary(*this, name);
+      load_okay = diskio::load_pgm_binary(*this, name, err_msg);
       break;
     
     default:
-      arma_stop("Mat::load(): unsupported file type");
+      arma_warn(print_status, "Mat::load(): unsupported file type");
+      load_okay = false;
     }
   
+  if( (print_status == true) && (load_okay == false) )
+    {
+    if(err_msg.length() > 0)
+      {
+      arma_print("Mat::load(): ", err_msg, name);
+      }
+    else
+      {
+      arma_print("Mat::load(): couldn't read ", name);
+      }
+    }
+  
+  if(load_okay == false)
+    {
+    (*this).reset();
+    }
+    
+  return load_okay;
   }
 
 
@@ -2718,37 +2785,112 @@ Mat<eT>::load(const std::string name, const file_type type)
 //! load a matrix from a stream
 template<typename eT>
 inline
-void
-Mat<eT>::load(std::istream& is, const file_type type)
+bool
+Mat<eT>::load(std::istream& is, const file_type type, const bool print_status)
   {
   arma_extra_debug_sigprint();
   
+  bool load_okay;
+  std::string err_msg;
+  
   switch(type)
     {
     case auto_detect:
-      diskio::load_auto_detect(*this, "[istream]", is);
+      load_okay = diskio::load_auto_detect(*this, is, err_msg);
       break;
     
     case raw_ascii:
-      diskio::load_raw_ascii(*this, "[istream]", is);
+      load_okay = diskio::load_raw_ascii(*this, is, err_msg);
       break;
     
     case arma_ascii:
-      diskio::load_arma_ascii(*this, "[istream]", is);
+      load_okay = diskio::load_arma_ascii(*this, is, err_msg);
       break;
     
     case arma_binary:
-      diskio::load_arma_binary(*this, "[istream]", is);
+      load_okay = diskio::load_arma_binary(*this, is, err_msg);
       break;
       
     case pgm_binary:
-      diskio::load_pgm_binary(*this, "[istream]", is);
+      load_okay = diskio::load_pgm_binary(*this, is, err_msg);
       break;
     
     default:
-      arma_stop("Mat::load(): unsupported file type");
+      arma_warn(print_status, "Mat::load(): unsupported file type");
+      load_okay = false;
     }
   
+  
+  if( (print_status == true) && (load_okay == false) )
+    {
+    if(err_msg.length() > 0)
+      {
+      arma_print("Mat::load(): ", err_msg, "the given stream");
+      }
+    else
+      {
+      arma_print("Mat::load(): couldn't load from the given stream");
+      }
+    }
+  
+  if(load_okay == false)
+    {
+    (*this).reset();
+    }
+    
+  return load_okay;
+  }
+
+
+
+//! save the matrix to a file, without printing any error messages
+template<typename eT>
+inline
+bool
+Mat<eT>::quiet_save(const std::string name, const file_type type) const
+  {
+  arma_extra_debug_sigprint();
+  
+  return (*this).save(name, type, false);
+  }
+
+
+
+//! save the matrix to a stream, without printing any error messages
+template<typename eT>
+inline
+bool
+Mat<eT>::quiet_save(std::ostream& os, const file_type type) const
+  {
+  arma_extra_debug_sigprint();
+  
+  return (*this).save(os, type, false);
+  }
+
+
+
+//! load a matrix from a file, without printing any error messages
+template<typename eT>
+inline
+bool
+Mat<eT>::quiet_load(const std::string name, const file_type type)
+  {
+  arma_extra_debug_sigprint();
+  
+  return (*this).load(name, type, false);
+  }
+
+
+
+//! load a matrix from a stream, without printing any error messages
+template<typename eT>
+inline
+bool
+Mat<eT>::quiet_load(std::istream& is, const file_type type)
+  {
+  arma_extra_debug_sigprint();
+  
+  return (*this).load(is, type, false);
   }
 
 
