@@ -380,6 +380,16 @@ Row<eT>::operator*=(const diagview<eT>& X)
 
 
 
+template<typename eT>
+inline
+mat_injector< Row<eT> >
+Row<eT>::operator<<(const eT val)
+  {
+  return mat_injector< Row<eT> >(*this, val);
+  }
+
+
+
 template<typename eT>
 arma_inline
 eT&
@@ -739,6 +749,20 @@ Row<eT>::set_size(const u32 in_n_rows, const u32 in_n_cols)
 
 
 
+template<typename eT>
+inline
+void
+Row<eT>::reshape(const u32 in_rows, const u32 in_cols, const u32 dim)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::reshape(in_rows, in_cols, dim);
+  
+  arma_debug_check( (in_rows > 1), "Row::set_size(): incompatible dimensions" );
+  }
+
+
+
 template<typename eT>
 template<typename eT2>
 inline
@@ -836,11 +860,11 @@ Row<eT>::ones(const u32 in_n_rows, const u32 in_n_cols)
 template<typename eT>
 inline
 void
-Row<eT>::load(const std::string name, const file_type type)
+Row<eT>::load(const std::string name, const file_type type, const bool print_status)
   {
   arma_extra_debug_sigprint();
   
-  Mat<eT>::load(name,type);
+  Mat<eT>::load(name, type, print_status);
   
   arma_debug_check( (Mat<eT>::n_rows > 1), "Row(): incompatible dimensions" );
   }
@@ -850,11 +874,39 @@ Row<eT>::load(const std::string name, const file_type type)
 template<typename eT>
 inline
 void
-Row<eT>::load(std::istream& is, const file_type type)
+Row<eT>::load(std::istream& is, const file_type type, const bool print_status)
   {
   arma_extra_debug_sigprint();
   
-  Mat<eT>::load(is, type);
+  Mat<eT>::load(is, type, print_status);
+  
+  arma_debug_check( (Mat<eT>::n_rows > 1), "Row(): incompatible dimensions" );
+  }
+
+
+
+template<typename eT>
+inline
+void
+Row<eT>::quiet_load(const std::string name, const file_type type)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::quiet_load(name, type);
+  
+  arma_debug_check( (Mat<eT>::n_rows > 1), "Row(): incompatible dimensions" );
+  }
+
+
+
+template<typename eT>
+inline
+void
+Row<eT>::quiet_load(std::istream& is, const file_type type)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::quiet_load(is, type);
   
   arma_debug_check( (Mat<eT>::n_rows > 1), "Row(): incompatible dimensions" );
   }
