@@ -23,7 +23,7 @@ class eglue_cube_plus : public eglue_cube_core<eglue_cube_plus>
   {
   public:
   
-  inline static const char* id() { return "cube addition"; }
+  inline static const char* text() { return "cube addition"; }
   };
 
 
@@ -32,7 +32,7 @@ class eglue_cube_minus : public eglue_cube_core<eglue_cube_minus>
   {
   public:
   
-  inline static const char* id() { return "cube subtraction"; }
+  inline static const char* text() { return "cube subtraction"; }
   };
 
 
@@ -41,7 +41,7 @@ class eglue_cube_div : public eglue_cube_core<eglue_cube_div>
   {
   public:
   
-  inline static const char* id() { return "element-wise cube division"; }
+  inline static const char* text() { return "element-wise cube division"; }
   };
 
 
@@ -50,7 +50,7 @@ class eglue_cube_schur : public eglue_cube_core<eglue_cube_schur>
   {
   public:
   
-  inline static const char* id() { return "element-wise cube multiplication"; }
+  inline static const char* text() { return "element-wise cube multiplication"; }
   };
 
 
