@@ -31,11 +31,12 @@ trace(const Base<typename T1::elem_type,T1>& X)
   
   const Proxy<T1> A(X.get_ref());
 
-  arma_debug_check( (A.n_rows != A.n_cols), "trace(): matrix must be square" );
+  arma_debug_check( (A.n_rows != A.n_cols), "trace(): matrix must be square sized" );
   
-  eT val = eT(0);
+  const u32 N   = A.n_rows;
+        eT  val = eT(0);
   
-  for(u32 i=0; i<A.n_rows; ++i)
+  for(u32 i=0; i<N; ++i)
     {
     val += A.at(i,i);
     }
@@ -70,5 +71,47 @@ trace(const Op<T1, op_diagmat>& X)
   }
 
 
+//! speedup for trace(A*B), where the result of A*B is a square sized matrix
+template<typename T1, typename T2>
+inline
+arma_warn_unused
+typename T1::elem_type
+trace(const Glue<T1, T2, glue_times>& X)
+  {
+  arma_extra_debug_sigprint();
+  
+  typedef typename T1::elem_type eT;
+  
+  const unwrap<T1> tmp1(X.A);
+  const unwrap<T2> tmp2(X.B);
+  
+  const Mat<eT>& A = tmp1.M;
+  const Mat<eT>& B = tmp2.M;
+  
+  arma_debug_assert_mul_size(A, B, "matrix multiply");
+  
+  arma_debug_check( (A.n_rows != B.n_cols), "trace(): matrix must be square sized" );
+  
+  const u32 N1  = A.n_rows;
+  const u32 N2  = A.n_cols;
+        eT  val = eT(0);
+  
+  for(u32 i=0; i<N1; ++i)
+    {
+    const eT* B_colmem = B.colptr(i);
+          eT  acc      = eT(0);
+    
+    for(u32 j=0; j<N2; ++j)
+      {
+      acc += A.at(i,j) * B_colmem[j];
+      }
+    
+    val += acc;
+    }
+  
+  return val;
+  }
+
+
 
 //! @}
